==> omniORB-4.1.5-i486-1sl.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libomniConnectionMgmt4.so.1 )
( cd usr/lib ; ln -sf libomniConnectionMgmt4.so.1.5 libomniConnectionMgmt4.so.1 )
( cd usr/lib ; rm -rf libCOS4.so )
( cd usr/lib ; ln -sf libCOS4.so.1 libCOS4.so )
( cd usr/lib ; rm -rf libomnithread.so )
( cd usr/lib ; ln -sf libomnithread.so.3 libomnithread.so )
( cd usr/lib ; rm -rf libCOSDynamic4.so.1 )
( cd usr/lib ; ln -sf libCOSDynamic4.so.1.5 libCOSDynamic4.so.1 )
( cd usr/lib ; rm -rf libomniDynamic4.so.1 )
( cd usr/lib ; ln -sf libomniDynamic4.so.1.5 libomniDynamic4.so.1 )
( cd usr/lib ; rm -rf libomniCodeSets4.so )
( cd usr/lib ; ln -sf libomniCodeSets4.so.1 libomniCodeSets4.so )
( cd usr/lib ; rm -rf libomniConnectionMgmt4.so )
( cd usr/lib ; ln -sf libomniConnectionMgmt4.so.1 libomniConnectionMgmt4.so )
( cd usr/lib ; rm -rf libomniORB4.so.1 )
( cd usr/lib ; ln -sf libomniORB4.so.1.5 libomniORB4.so.1 )
( cd usr/lib ; rm -rf libCOS4.so.1 )
( cd usr/lib ; ln -sf libCOS4.so.1.5 libCOS4.so.1 )
( cd usr/lib ; rm -rf libCOSDynamic4.so )
( cd usr/lib ; ln -sf libCOSDynamic4.so.1 libCOSDynamic4.so )
( cd usr/lib ; rm -rf libomniORB4.so )
( cd usr/lib ; ln -sf libomniORB4.so.1 libomniORB4.so )
( cd usr/lib ; rm -rf libomniDynamic4.so )
( cd usr/lib ; ln -sf libomniDynamic4.so.1 libomniDynamic4.so )
( cd usr/lib ; rm -rf libomnithread.so.3 )
( cd usr/lib ; ln -sf libomnithread.so.3.4 libomnithread.so.3 )
( cd usr/lib/python2.6/site-packages ; rm -rf _omniidlmodule.so )
( cd usr/lib/python2.6/site-packages ; ln -sf _omniidlmodule.so.4 _omniidlmodule.so )
( cd usr/lib/python2.6/site-packages ; rm -rf _omniidlmodule.so.4 )
( cd usr/lib/python2.6/site-packages ; ln -sf _omniidlmodule.so.4.1 _omniidlmodule.so.4 )
( cd usr/lib ; rm -rf libomniCodeSets4.so.1 )
( cd usr/lib ; ln -sf libomniCodeSets4.so.1.5 libomniCodeSets4.so.1 )

==> omniORB-4.1.6-i486-1sl.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libomniCodeSets4.so.1 )
( cd usr/lib ; ln -sf libomniCodeSets4.so.1.6 libomniCodeSets4.so.1 )
( cd usr/lib ; rm -rf libomnithread.so )
( cd usr/lib ; ln -sf libomnithread.so.3 libomnithread.so )
( cd usr/lib ; rm -rf libCOSDynamic4.so.1 )
( cd usr/lib ; ln -sf libCOSDynamic4.so.1.6 libCOSDynamic4.so.1 )
( cd usr/lib ; rm -rf libomniConnectionMgmt4.so )
( cd usr/lib ; ln -sf libomniConnectionMgmt4.so.1 libomniConnectionMgmt4.so )
( cd usr/lib ; rm -rf libomniDynamic4.so )
( cd usr/lib ; ln -sf libomniDynamic4.so.1 libomniDynamic4.so )
( cd usr/lib ; rm -rf libomniDynamic4.so.1 )
( cd usr/lib ; ln -sf libomniDynamic4.so.1.6 libomniDynamic4.so.1 )
( cd usr/lib ; rm -rf libomniConnectionMgmt4.so.1 )
( cd usr/lib ; ln -sf libomniConnectionMgmt4.so.1.6 libomniConnectionMgmt4.so.1 )
( cd usr/lib ; rm -rf libCOSDynamic4.so )
( cd usr/lib ; ln -sf libCOSDynamic4.so.1 libCOSDynamic4.so )
( cd usr/lib/python2.7/site-packages ; rm -rf _omniidlmodule.so.4 )
( cd usr/lib/python2.7/site-packages ; ln -sf _omniidlmodule.so.4.1 _omniidlmodule.so.4 )
( cd usr/lib/python2.7/site-packages ; rm -rf _omniidlmodule.so )
( cd usr/lib/python2.7/site-packages ; ln -sf _omniidlmodule.so.4 _omniidlmodule.so )
( cd usr/lib ; rm -rf libomniCodeSets4.so )
( cd usr/lib ; ln -sf libomniCodeSets4.so.1 libomniCodeSets4.so )
( cd usr/lib ; rm -rf libCOS4.so.1 )
( cd usr/lib ; ln -sf libCOS4.so.1.6 libCOS4.so.1 )
( cd usr/lib ; rm -rf libCOS4.so )
( cd usr/lib ; ln -sf libCOS4.so.1 libCOS4.so )
( cd usr/lib ; rm -rf libomniORB4.so.1 )
( cd usr/lib ; ln -sf libomniORB4.so.1.6 libomniORB4.so.1 )
( cd usr/lib ; rm -rf libomnithread.so.3 )
( cd usr/lib ; ln -sf libomnithread.so.3.4 libomnithread.so.3 )
( cd usr/lib ; rm -rf libomniORB4.so )
( cd usr/lib ; ln -sf libomniORB4.so.1 libomniORB4.so )
